@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2003-2008 Zuza Software Foundation
@@ -26,7 +26,8 @@ for examples and usage instructions.
 """
 
 import logging
-from urllib import urlencode
+from six.moves.urllib import parse
+
 
 from translate.storage import oo, xliff
 
@@ -36,7 +37,7 @@ from translate.storage import oo, xliff
 logger = logging.getLogger(__name__)
 
 
-class oo2xliff:
+class oo2xliff(object):
 
     def __init__(self, sourcelanguage, targetlanguage, blankmsgstr=False, long_keys=False):
         """construct an oo2xliff converter for the specified languages"""
@@ -100,7 +101,7 @@ class oo2xliff:
         thetargetfile.settargetlanguage(self.targetlanguage)
         # create a header for the file
         bug_url = 'http://qa.openoffice.org/issues/enter_bug.cgi?%s' % \
-                  urlencode({
+                  parse.urlencode({
                       "subcomponent": "ui",
                       "comment": "",
                       "short_desc": "Localization issue in file: %s" %
@@ -137,7 +138,7 @@ def convertoo(inputfile, outputfile, templates, pot=False, sourcelanguage=None,
             sourcelanguage = "01"
         else:
             sourcelanguage = "en-US"
-    if not sourcelanguage in inputstore.languages:
+    if sourcelanguage not in inputstore.languages:
         logger.warning("sourcelanguage '%s' not found in inputfile '%s' "
                        "(contains %s)",
                        sourcelanguage, inputfilename,
@@ -153,16 +154,16 @@ def convertoo(inputfile, outputfile, templates, pot=False, sourcelanguage=None,
     outputstore = convertor.convertstore(inputstore, duplicatestyle)
     if outputstore.isempty():
         return 0
-    outputfile.write(str(outputstore))
+    outputstore.serialize(outputfile)
     return 1
 
 
 def main(argv=None):
     from translate.convert import convert
     formats = {
-                "oo": ("xlf", convertoo),
-                "sdf": ("xlf", convertoo),
-              }
+        "oo": ("xlf", convertoo),
+        "sdf": ("xlf", convertoo),
+    }
     # always treat the input as an archive unless it is a directory
     archiveformats = {(None, "input"): oo.oomultifile}
     parser = convert.ArchiveConvertOptionParser(formats, usepots=False,
@@ -171,8 +172,9 @@ def main(argv=None):
     parser.add_option("-l", "--language", dest="targetlanguage", default=None,
                       help="set target language to extract from oo file (e.g. af-ZA)",
                       metavar="LANG")
-    parser.add_option("", "--source-language", dest="sourcelanguage", default=None,
-            help="set source language code (default en-US)", metavar="LANG")
+    parser.add_option(
+        "", "--source-language", dest="sourcelanguage", default=None,
+        help="set source language code (default en-US)", metavar="LANG")
     parser.add_option("", "--nonrecursiveinput", dest="allowrecursiveinput",
                       default=True, action="store_false",
                       help="don't treat the input oo as a recursive store")
