@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2002-2006,2008-2009 Zuza Software Foundation
@@ -24,11 +24,13 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
+import six
+
 from translate.convert import convert
 from translate.storage import po, rc
 
 
-class rerc:
+class rerc(object):
 
     def __init__(self, templatefile, charset="utf-8", lang=None, sublang=None):
         self.templatefile = templatefile
@@ -49,7 +51,7 @@ class rerc:
         return outputblocks
 
     def makestoredict(self, store, includefuzzy=False):
-        """ make a dictionary of the translations"""
+        """make a dictionary of the translations"""
         for unit in store.units:
             if includefuzzy or not unit.isfuzzy():
                 for location in unit.getlocations():
@@ -60,7 +62,7 @@ class rerc:
 
     def convertblock(self, block):
         newblock = block
-        if isinstance(newblock, unicode):
+        if isinstance(newblock, six.text_type):
             newblock = newblock.encode('utf-8')
         if newblock.startswith("LANGUAGE"):
             return "LANGUAGE %s, %s" % (self.lang, self.sublang)
@@ -71,7 +73,7 @@ class rerc:
                     newmatch = unit.match.group().replace(unit.match.groupdict()['value'],
                                                           self.inputdict[location])
                     newblock = newblock.replace(unit.match.group(), newmatch)
-        if isinstance(newblock, unicode):
+        if isinstance(newblock, six.text_type):
             newblock = newblock.encode(self.charset)
         return newblock
 
@@ -101,13 +103,16 @@ def main(argv=None):
     parser = convert.ConvertOptionParser(formats, usetemplates=True,
                                          description=__doc__)
     defaultcharset = "utf-8"
-    parser.add_option("", "--charset", dest="charset", default=defaultcharset,
+    parser.add_option(
+        "", "--charset", dest="charset", default=defaultcharset,
         help="charset to use to decode the RC files (default: %s)" % defaultcharset,
         metavar="CHARSET")
-    parser.add_option("-l", "--lang", dest="lang", default=None,
+    parser.add_option(
+        "-l", "--lang", dest="lang", default=None,
         help="LANG entry", metavar="LANG")
     defaultsublang = "SUBLANG_DEFAULT"
-    parser.add_option("", "--sublang", dest="sublang", default=defaultsublang,
+    parser.add_option(
+        "", "--sublang", dest="sublang", default=defaultsublang,
         help="SUBLANG entry (default: %s)" % defaultsublang, metavar="SUBLANG")
     parser.passthrough.append("charset")
     parser.passthrough.append("lang")
@@ -116,5 +121,6 @@ def main(argv=None):
     parser.add_fuzzy_option()
     parser.run(argv)
 
+
 if __name__ == '__main__':
     main()
