@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 #
 # Copyright 2004-2007 Zuza Software Foundation
 #
@@ -30,6 +30,7 @@ for full descriptions of all tests.
 """
 
 import os
+import six
 
 from translate.filters import autocorrect, checks
 from translate.misc import optrecurse
@@ -39,7 +40,8 @@ from translate.storage.poheader import poheader
 
 def build_checkerconfig(options):
     """Prepare the checker config from the given options.  This is mainly
-    factored out for the sake of unit tests."""
+    factored out for the sake of unit tests.
+    """
     checkerconfig = checks.CheckerConfig(targetlanguage=options.targetlanguage)
 
     if options.notranslatefile:
@@ -48,7 +50,8 @@ def build_checkerconfig(options):
         if not os.path.exists(options.notranslatefile):
             self.error("notranslatefile %r does not exist" % options.notranslatefile)
 
-        notranslatewords = [line.strip() for line in open(options.notranslatefile).readlines()]
+        with open(options.notranslatefile, 'r') as fp:
+            notranslatewords = [line.strip() for line in fp.readlines()]
         notranslatewords = dict.fromkeys([key for key in notranslatewords])
 
         checkerconfig.notranslatewords.update(notranslatewords)
@@ -59,7 +62,8 @@ def build_checkerconfig(options):
         if not os.path.exists(options.musttranslatefile):
             self.error("musttranslatefile %r does not exist" % options.musttranslatefile)
 
-        musttranslatewords = [line.strip() for line in open(options.musttranslatefile).readlines()]
+        with open(options.musttranslatefile, 'r') as fp:
+            musttranslatewords = [line.strip() for line in fp.readlines()]
         musttranslatewords = dict.fromkeys([key for key in musttranslatewords])
 
         checkerconfig.musttranslatewords.update(musttranslatewords)
@@ -70,14 +74,15 @@ def build_checkerconfig(options):
         if not os.path.exists(options.validcharsfile):
             self.error("validcharsfile %r does not exist" % options.validcharsfile)
 
-        validchars = open(options.validcharsfile).read()
+        with open(options.validcharsfile, 'r') as fp:
+            validchars = fp.read()
 
         checkerconfig.updatevalidchars(validchars)
 
     return checkerconfig
 
 
-class pocheckfilter:
+class pocheckfilter(object):
 
     def __init__(self, options, checkerclasses=None, checkerconfig=None):
         # excludefilters={}, limitfilters=None, includefuzzy=True, includereview=True, autocorrect=False):
@@ -92,17 +97,15 @@ class pocheckfilter:
                                          languagecode=checkerconfig.targetlanguage)
         self.options = options
 
-
     def getfilterdocs(self):
         """Lists the docs for filters available on checker."""
         filterdict = self.checker.getfilters()
         filterdocs = ["%s\t%s" % (name, filterfunc.__doc__.split('\n\n')[0])
-                      for (name, filterfunc) in filterdict.iteritems()]
+                      for (name, filterfunc) in six.iteritems(filterdict)]
         filterdocs.sort()
 
         return "\n".join(filterdocs)
 
-
     def filterunit(self, unit):
         """Runs filters on an element."""
 
@@ -130,7 +133,6 @@ class pocheckfilter:
 
         return failures
 
-
     def filterfile(self, transfile):
         """Runs filters on a translation store object.
 
@@ -147,7 +149,7 @@ class pocheckfilter:
 
             if filter_result:
                 if filter_result != autocorrect:
-                    for filter_name in filter_result.iterkeys():
+                    for filter_name in six.iterkeys(filter_result):
                         filter_message = filter_result[filter_name]['message']
 
                         if self.options.addnotes:
@@ -171,21 +173,22 @@ class FilterOptionParser(optrecurse.RecursiveOptionParser):
         optrecurse.RecursiveOptionParser.__init__(self, formats)
 
         self.set_usage()
-        self.add_option("-l", "--listfilters", action="callback", dest='listfilters',
+        self.add_option(
+            "-l", "--listfilters", action="callback", dest='listfilters',
             default=False, callback_kwargs={'dest_value': True},
             callback=self.parse_noinput, help="list filters available")
 
-
     def parse_noinput(self, option, opt, value, parser, *args, **kwargs):
-        """This sets an option to *True*, but also sets input to *-*
-        to prevent an error."""
+        """This sets an option to *True*, but also sets input to *-* to prevent
+        an error.
+        """
         setattr(parser.values, option.dest, kwargs['dest_value'])
         parser.values.input = "-"
 
-
     def run(self):
-        """Parses the arguments, and runs recursiveprocess with the
-        resulting options."""
+        """Parses the arguments, and runs recursiveprocess with the resulting
+        options.
+        """
         (options, args) = self.parse_args()
 
         if options.filterclass is None:
@@ -199,9 +202,6 @@ class FilterOptionParser(optrecurse.RecursiveOptionParser):
         if not options.checkfilter.checker.combinedfilters:
             self.error("No valid filters were specified")
 
-        options.inputformats = self.inputformats
-        options.outputoptions = self.outputoptions
-
         if options.listfilters:
             print(options.checkfilter.getfilterdocs())
         else:
@@ -216,73 +216,94 @@ def runfilter(inputfile, outputfile, templatefile, checkfilter=None):
     if tofile.isempty():
         return 0
 
-    outputfile.write(str(tofile))
+    tofile.serialize(outputfile)
 
     return 1
 
 
 def cmdlineparser():
-    formats = {"po": ("po", runfilter), "pot": ("pot", runfilter),
-            "xliff": ("xliff", runfilter), "xlf": ("xlf", runfilter),
-            "tmx": ("tmx", runfilter),
-            None: ("po", runfilter)}
+    formats = {
+        "po": ("po", runfilter), "pot": ("pot", runfilter),
+        "xliff": ("xliff", runfilter), "xlf": ("xlf", runfilter),
+        "tmx": ("tmx", runfilter),
+        None: ("po", runfilter),
+    }
 
     parser = FilterOptionParser(formats)
 
-    parser.add_option("", "--review", dest="includereview",
+    parser.add_option(
+        "", "--review", dest="includereview",
         action="store_true", default=True,
         help="include units marked for review (default)")
-    parser.add_option("", "--noreview", dest="includereview",
+    parser.add_option(
+        "", "--noreview", dest="includereview",
         action="store_false", default=True,
         help="exclude units marked for review")
-    parser.add_option("", "--fuzzy", dest="includefuzzy",
+    parser.add_option(
+        "", "--fuzzy", dest="includefuzzy",
         action="store_true", default=True,
         help="include units marked fuzzy (default)")
-    parser.add_option("", "--nofuzzy", dest="includefuzzy",
+    parser.add_option(
+        "", "--nofuzzy", dest="includefuzzy",
         action="store_false", default=True,
         help="exclude units marked fuzzy")
-    parser.add_option("", "--nonotes", dest="addnotes",
+    parser.add_option(
+        "", "--nonotes", dest="addnotes",
         action="store_false", default=True,
         help="don't add notes about the errors")
-    parser.add_option("", "--autocorrect", dest="autocorrect",
+    parser.add_option(
+        "", "--autocorrect", dest="autocorrect",
         action="store_true", default=False,
         help="output automatic corrections where possible rather than describing issues")
-    parser.add_option("", "--language", dest="targetlanguage", default=None,
+    parser.add_option(
+        "", "--language", dest="targetlanguage", default=None,
         help="set target language code (e.g. af-ZA) [required for spell check and recommended in general]", metavar="LANG")
-    parser.add_option("", "--openoffice", dest="filterclass",
+    parser.add_option(
+        "", "--openoffice", dest="filterclass",
         action="store_const", default=None, const=checks.OpenOfficeChecker,
         help="use the standard checks for OpenOffice translations")
-    parser.add_option("", "--libreoffice", dest="filterclass",
+    parser.add_option(
+        "", "--libreoffice", dest="filterclass",
         action="store_const", default=None, const=checks.LibreOfficeChecker,
         help="use the standard checks for LibreOffice translations")
-    parser.add_option("", "--mozilla", dest="filterclass",
+    parser.add_option(
+        "", "--mozilla", dest="filterclass",
         action="store_const", default=None, const=checks.MozillaChecker,
         help="use the standard checks for Mozilla translations")
-    parser.add_option("", "--drupal", dest="filterclass",
+    parser.add_option(
+        "", "--drupal", dest="filterclass",
         action="store_const", default=None, const=checks.DrupalChecker,
         help="use the standard checks for Drupal translations")
-    parser.add_option("", "--gnome", dest="filterclass",
+    parser.add_option(
+        "", "--gnome", dest="filterclass",
         action="store_const", default=None, const=checks.GnomeChecker,
         help="use the standard checks for Gnome translations")
-    parser.add_option("", "--kde", dest="filterclass",
+    parser.add_option(
+        "", "--kde", dest="filterclass",
         action="store_const", default=None, const=checks.KdeChecker,
         help="use the standard checks for KDE translations")
-    parser.add_option("", "--wx", dest="filterclass",
+    parser.add_option(
+        "", "--wx", dest="filterclass",
         action="store_const", default=None, const=checks.KdeChecker,
         help="use the standard checks for wxWidgets translations")
-    parser.add_option("", "--excludefilter", dest="excludefilters",
+    parser.add_option(
+        "", "--excludefilter", dest="excludefilters",
         action="append", default=[], type="string", metavar="FILTER",
         help="don't use FILTER when filtering")
-    parser.add_option("-t", "--test", dest="limitfilters",
+    parser.add_option(
+        "-t", "--test", dest="limitfilters",
         action="append", default=None, type="string", metavar="FILTER",
         help="only use test FILTERs specified with this option when filtering")
-    parser.add_option("", "--notranslatefile", dest="notranslatefile",
+    parser.add_option(
+        "", "--notranslatefile", dest="notranslatefile",
         default=None, type="string", metavar="FILE",
         help="read list of untranslatable words from FILE (must not be translated)")
-    parser.add_option("", "--musttranslatefile", dest="musttranslatefile",
+    parser.add_option(
+        "", "--musttranslatefile", dest="musttranslatefile",
         default=None, type="string", metavar="FILE",
         help="read list of translatable words from FILE (must be translated)")
-    parser.add_option("", "--validcharsfile", dest="validcharsfile",
+    parser.add_option(
+        "", "--validcharsfile", dest="validcharsfile",
         default=None, type="string", metavar="FILE",
         help="read list of all valid characters from FILE (must be in UTF-8)")
 
