@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2007-2011 Zuza Software Foundation
@@ -20,6 +19,12 @@
 
 """This module stores information and functionality that relates to plurals."""
 
+import gettext
+import locale
+import os
+import re
+import six
+
 
 languages = {
     'ach': (u'Acholi', 2, 'n > 1'),
@@ -39,6 +44,7 @@ languages = {
            'n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2'),
     'bg': (u'Bulgarian', 2, '(n != 1)'),
     'bn': (u'Bengali', 2, '(n != 1)'),
+    'bn_BD': (u'Bengali (Bangladesh)', 2, '(n != 1)'),
     'bn_IN': (u'Bengali (India)', 2, '(n != 1)'),
     'bo': (u'Tibetan', 1, '0'),
     'br': (u'Breton', 2, 'n > 1'),
@@ -65,7 +71,7 @@ languages = {
     'es_AR': (u'Argentinean Spanish', 2, '(n != 1)'),
     'et': (u'Estonian', 2, '(n != 1)'),
     'eu': (u'Basque', 2, '(n != 1)'),
-    'fa': (u'Persian', 1, '0'),
+    'fa': (u'Persian', 2, 'n > 1'),
     'ff': (u'Fulah', 2, '(n != 1)'),
     'fi': (u'Finnish', 2, '(n != 1)'),
     'fil': (u'Filipino; Pilipino', 2, '(n > 1)'),
@@ -94,27 +100,30 @@ languages = {
     'jbo': (u'Lojban', 1, '0'),
     'jv': (u'Javanese', 2, '(n != 1)'),
     'ka': (u'Georgian', 1, '0'),
-    'kk': (u'Kazakh', 1, '0'),
+    'kk': (u'Kazakh', 2, 'n != 1'),
     'kl': (u'Greenlandic', 2, '(n != 1)'),
     'km': (u'Central Khmer', 1, '0'),
     'kn': (u'Kannada', 2, '(n != 1)'),
     'ko': (u'Korean', 1, '0'),
+    'kok': (u'Konkani', 2, '(n != 1)'),
+    'ks': (u'Kashmiri', 2, '(n != 1)'),
     'ku': (u'Kurdish', 2, '(n != 1)'),
     'kw': (u'Cornish', 4, '(n==1) ? 0 : (n==2) ? 1 : (n == 3) ? 2 : 3'),
-    'ky': (u'Kirghiz; Kyrgyz', 1, '0'),
+    'ky': (u'Kirghiz; Kyrgyz', 2, 'n != 1'),
     'lb': (u'Luxembourgish; Letzeburgesch', 2, '(n != 1)'),
     'ln': (u'Lingala', 2, '(n > 1)'),
     'lo': (u'Lao', 1, '0'),
     'lt': (u'Lithuanian', 3, '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2)'),
     'lv': (u'Latvian', 3, '(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2)'),
     'mai': (u'Maithili', 2, '(n != 1)'),
+    'me': (u'Montenegro', 3, 'n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2'),
     'mfe': (u'Morisyen', 2, '(n > 1)'),
     'mg': (u'Malagasy', 2, '(n > 1)'),
     'mi': (u'Maori', 2, '(n > 1)'),
-    'mk': (u'Macedonian', 2, 'n==1 || n%10==1 ? 0 : 1'),
+    'mk': (u'Macedonian', 2, '(n==1 || n%10==1 ? 0 : 1)'),
     'ml': (u'Malayalam', 2, '(n != 1)'),
     'mn': (u'Mongolian', 2, '(n != 1)'),
-    'mni': (u'Manipuri', 2, '(n != 1)'),
+    'mni': (u'Meithei (Manipuri)', 2, '(n != 1)'),
     'mnk': (u'Mandinka', 3, '(n==0 ? 0 : n==1 ? 1 : 2)'),
     'mr': (u'Marathi', 2, '(n != 1)'),
     'ms': (u'Malay', 1, '0'),
@@ -130,7 +139,7 @@ languages = {
     'nqo': (u"N'Ko", 2, '(n > 1)'),
     'nso': (u'Pedi; Sepedi; Northern Sotho', 2, '(n != 1)'),
     'oc': (u'Occitan (post 1500)', 2, '(n > 1)'),
-    'or': (u'Oriya', 2, '(n != 1)'),
+    'or': (u'Odia', 2, '(n != 1)'),
     'pa': (u'Panjabi; Punjabi', 2, '(n != 1)'),
     'pap': (u'Papiamento', 2, '(n != 1)'),
     'pl': (u'Polish', 3,
@@ -142,8 +151,9 @@ languages = {
     'rm': (u'Romansh', 2, '(n != 1)'),
     'ro': (u'Romanian', 3, '(n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < 20)) ? 1 : 2);'),
     'ru': (u'Russian', 3,
-          '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
+           '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
     'rw': (u'Kinyarwanda', 2, '(n != 1)'),
+    'sa': (u'Sanskrit', 3, '(n==1 ? 0 : n==2 ? 1 : 2)'),
     'sah': (u'Yakut', 1, '0'),
     'sat': (u'Santali', 2, '(n != 1)'),
     'sco': (u'Scots', 2, '(n != 1)'),
@@ -153,7 +163,7 @@ languages = {
     'sk': (u'Slovak', 3, '(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2'),
     'sl': (u'Slovenian', 4, '(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3)'),
     'so': (u'Somali', 2, '(n != 1)'),
-    'son': (u'Songhai languages', 2, '(n != 1)'),
+    'son': (u'Songhai languages', 1, '0'),
     'sq': (u'Albanian', 2, '(n != 1)'),
     'sr': (u'Serbian', 3,
            '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
@@ -161,13 +171,15 @@ languages = {
     'su': (u'Sundanese', 1, '0'),
     'sv': (u'Swedish', 2, '(n != 1)'),
     'sw': (u'Swahili', 2, '(n != 1)'),
+    'szl': (u'Silesian', 3,
+            '(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
     'ta': (u'Tamil', 2, '(n != 1)'),
     'te': (u'Telugu', 2, '(n != 1)'),
-    'tg': (u'Tajik', 2, '(n != 1)'),
+    'tg': (u'Tajik', 1, '0'),
     'th': (u'Thai', 1, '0'),
     'ti': (u'Tigrinya', 2, '(n > 1)'),
     'tk': (u'Turkmen', 2, '(n != 1)'),
-    'tr': (u'Turkish', 1, '0'),
+    'tr': (u'Turkish', 2, '(n != 1)'),
     'tt': (u'Tatar', 1, '0'),
     'ug': (u'Uighur; Uyghur', 1, '0'),
     'uk': (u'Ukrainian', 3,
@@ -179,6 +191,7 @@ languages = {
     'wa': (u'Walloon', 2, '(n > 1)'),
     'wo': (u'Wolof', 2, '(n != 1)'),
     'yo': (u'Yoruba', 2, '(n != 1)'),
+    'yue': (u'Yue', 1, '0'),
     # Chinese is difficult because the main divide is on script, not really
     # country. Simplified Chinese is used mostly in China, Singapore and Malaysia.
     # Traditional Chinese is used mostly in Hong Kong, Taiwan and Macau.
@@ -227,13 +240,85 @@ _fixed_names = {
 }
 
 
+scripts = {
+    # Codes pulled from http://unicode.org/iso15924/iso15924-codes.html
+    # Scripts were figured out from the languages's Wikipedia pages and the
+    # real usage in https://mozilla.locamotion.org/
+    'Deva': [
+        'anp',  # https://en.wikipedia.org/wiki/Angika_language
+        'bho',  # https://en.wikipedia.org/wiki/Bhojpuri_language
+        'brx',  # https://en.wikipedia.org/wiki/Bodo_language
+        'doi',  # https://en.wikipedia.org/wiki/Dogri_language
+        'hi',   # https://en.wikipedia.org/wiki/Hindi
+        'kfy',  # https://en.wikipedia.org/wiki/Kumaoni_language
+        'kok',  # https://en.wikipedia.org/wiki/Konkani_language
+        'mai',  # https://en.wikipedia.org/wiki/Maithili_language
+        'mr',   # https://en.wikipedia.org/wiki/Marathi_language
+        'sa',   # https://en.wikipedia.org/wiki/Sanskrit
+        'sat',  # https://en.wikipedia.org/wiki/Santali_language
+    ],
+    'Beng': [
+        'bn',   # https://en.wikipedia.org/wiki/Bengali_language
+        'mni',  # https://en.wikipedia.org/wiki/Manipuri_language
+    ],
+    'Tibt': [
+        'bo',  # https://en.wikipedia.org/wiki/Standard_Tibetan
+    ],
+    'Orya': [
+        'or',  # https://en.wikipedia.org/wiki/Odia_language
+    ],
+    'Gujr': [
+        'gu',  # https://en.wikipedia.org/wiki/Gujarati_language
+    ],
+    'Khmr': [
+        'km',  # https://en.wikipedia.org/wiki/Khmer_language
+    ],
+    'Knda': [
+        'kn',  # https://en.wikipedia.org/wiki/Kannada
+    ],
+    'Laoo': [
+        'lo',  # https://en.wikipedia.org/wiki/Lao_language
+    ],
+    'Mlym': [
+        'ml',  # https://en.wikipedia.org/wiki/Malayalam
+    ],
+    'Mymr': [
+        'my',   # https://en.wikipedia.org/wiki/Burmese_language
+        'shn',  # https://en.wikipedia.org/wiki/Shan_language
+    ],
+    'Sind': [
+        'sd',  # https://en.wikipedia.org/wiki/Sindhi_language
+    ],
+    'Taml': [
+        'ta',  # https://en.wikipedia.org/wiki/Tamil_language
+    ],
+    # Unable to find the codes for the following scripts.
+    'assamese': [
+        'as',  # https://en.wikipedia.org/wiki/Assamese_language
+    ],
+    'perso-arabic': [
+        'ks',  # https://en.wikipedia.org/wiki/Kashmiri_language
+    ],
+    'chinese': [
+        'yue',  # https://en.wikipedia.org/wiki/Yue_Chinese
+    ],
+}
+"""Dictionary of scripts data.
+The dictionary keys are ISO 15924 script codes, and script names where scripts
+are missing from standard. The value is a list of codes for languages using
+that script.
+
+This is mainly used to alter the behavior of some checks (the accelerators one
+for example)."""
+
+
 cldr_plural_categories = [
-        'zero',
-        'one',
-        'two',
-        'few',
-        'many',
-        'other',
+    'zero',
+    'one',
+    'two',
+    'few',
+    'many',
+    'other',
 ]
 
 
@@ -260,20 +345,14 @@ def simplercode(code):
 
 
 expansion_factors = {
-        'af': 0.1,
-        'ar': -0.09,
-        'es': 0.21,
-        'fr': 0.28,
-        'it': 0.2,
+    'af': 0.1,
+    'ar': -0.09,
+    'es': 0.21,
+    'fr': 0.28,
+    'it': 0.2,
 }
 """Source to target string length expansion factors."""
 
-import gettext
-import locale
-import os
-import re
-
-
 iso639 = {}
 """ISO 639 language codes"""
 iso3166 = {}
@@ -289,9 +368,10 @@ def languagematch(languagecode, otherlanguagecode):
     """matches a languagecode to another, ignoring regions in the second"""
     if languagecode is None:
         return langcode_re.match(otherlanguagecode)
-    return languagecode == otherlanguagecode or \
-           (otherlanguagecode.startswith(languagecode) and
-            variant_re.match(otherlanguagecode[len(languagecode):]))
+    return (languagecode == otherlanguagecode or
+            (otherlanguagecode.startswith(languagecode) and
+             variant_re.match(otherlanguagecode[len(languagecode):])))
+
 
 dialect_name_re = re.compile(r"(.+)\s\(([^)\d]{,25})\)$")
 # The limit of 25 characters on the country name is so that "Interlingua (...)"
@@ -299,9 +379,10 @@ dialect_name_re = re.compile(r"(.+)\s\(([^)\d]{,25})\)$")
 
 
 def tr_lang(langcode=None):
-    """Gives a function that can translate a language name, even in the
-    form ``"language (country)"``, into the language with iso code langcode,
-    or the system language if no language is specified."""
+    """Gives a function that can translate a language name, even in the form
+    ``"language (country)"``, into the language with iso code langcode, or the
+    system language if no language is specified.
+    """
     langfunc = gettext_lang(langcode)
     countryfunc = gettext_country(langcode)
 
@@ -320,10 +401,11 @@ def tr_lang(langcode=None):
 def _fix_language_name(name):
     """Identify and replace some unsightly names present in iso-codes.
 
-    If the name is present in _fixed_names we assume it is untranslated and
-    we replace it with a more usable rendering.  If the remaining part is long
-    and includes a semi-colon, we only take the text up to the semi-colon to
-    keep things neat."""
+    If the name is present in _fixed_names we assume it is untranslated and we
+    replace it with a more usable rendering.  If the remaining part is long and
+    includes a semi-colon, we only take the text up to the semi-colon to keep
+    things neat.
+    """
     if name in _fixed_names:
         return _fixed_names[name]
     elif len(name) > 11:
@@ -337,8 +419,9 @@ def _fix_language_name(name):
 
 def gettext_lang(langcode=None):
     """Returns a gettext function to translate language names into the given
-    language, or the system language if no language is specified."""
-    if not langcode in iso639:
+    language, or the system language if no language is specified.
+    """
+    if langcode not in iso639:
         if not langcode:
             langcode = ""
             if os.name == "nt":
@@ -351,14 +434,15 @@ def gettext_lang(langcode=None):
         else:
             t = gettext.translation('iso_639', languages=[langcode],
                                     fallback=True)
-        iso639[langcode] = t.ugettext
+        iso639[langcode] = t.ugettext if six.PY2 else t.gettext
     return iso639[langcode]
 
 
 def gettext_country(langcode=None):
     """Returns a gettext function to translate country names into the given
-    language, or the system language if no language is specified."""
-    if not langcode in iso3166:
+    language, or the system language if no language is specified.
+    """
+    if langcode not in iso3166:
         if not langcode:
             langcode = ""
             if os.name == "nt":
@@ -371,16 +455,16 @@ def gettext_country(langcode=None):
         else:
             t = gettext.translation('iso_3166', languages=[langcode],
                                     fallback=True)
-        iso3166[langcode] = t.ugettext
+        iso3166[langcode] = t.ugettext if six.PY2 else t.gettext
     return iso3166[langcode]
 
 
 def normalize(string, normal_form="NFC"):
     """Return a unicode string in its normalized form
 
-       :param string: The string to be normalized
-       :param normal_form: NFC (default), NFD, NFKC, NFKD
-       :return: Normalized string
+    :param string: The string to be normalized
+    :param normal_form: NFC (default), NFD, NFKC, NFKD
+    :return: Normalized string
     """
     if string is None:
         return None
@@ -392,19 +476,19 @@ def normalize(string, normal_form="NFC"):
 def forceunicode(string):
     """Ensures that the string is in unicode.
 
-       :param string: A text string
-       :type string: Unicode, String
-       :return: String converted to Unicode and normalized as needed.
-       :rtype: Unicode
+    :param string: A text string
+    :type string: Unicode, String
+    :return: String converted to Unicode and normalized as needed.
+    :rtype: Unicode
     """
     if string is None:
         return None
     from translate.storage.placeables import StringElem
-    if isinstance(string, str):
+    if isinstance(string, bytes):
         encoding = getattr(string, "encoding", "utf-8")
         string = string.decode(encoding)
     elif isinstance(string, StringElem):
-        string = unicode(string)
+        string = six.text_type(string)
     return string
 
 
@@ -423,9 +507,10 @@ __normalised_languages = set(normalize_code(key) for key in languages.keys())
 
 
 def simplify_to_common(language_code, languages=languages):
-    """Simplify language code to the most commonly used form for the
-    language, stripping country information for languages that tend
-    not to be localized differently for different countries"""
+    """Simplify language code to the most commonly used form for the language,
+    stripping country information for languages that tend not to be localized
+    differently for different countries
+    """
     simpler = simplercode(language_code)
     if simpler == "":
         return language_code
