@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
@@ -29,4 +28,6 @@ from translate.lang import common
 class de(common.Common):
     """This class represents German."""
 
-    ignoretests = ["simplecaps"]
+    ignoretests = {
+        'all': ["simplecaps"],
+    }
