@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
@@ -29,4 +28,4 @@ from translate.lang import common
 class gd(common.Common):
     """This class represents Gaelic."""
 
-    specialchars = u'àòùèìÀÈÌÒÙ'
+    specialchars = u'àòùèìÀÈÌÒÙ⁊┐’…“”»‌‑'
