@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
@@ -29,4 +28,6 @@ from translate.lang import common
 class ko(common.Common):
     """This class represents Korean."""
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        'all': ["simplecaps", "startcaps"],
+    }
