@@ -1,7 +1,6 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
-# Copyright 2008 Zuza Software Foundation
+# Copyright 2008, 2016 Zuza Software Foundation
 #
 # This file is part of translate.
 #
@@ -29,4 +28,6 @@ from translate.lang import common
 class ml(common.Common):
     """This class represents Malayalam."""
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        'all': ["simplecaps", "startcaps"],
+    }
