@@ -1,7 +1,6 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
-# Copyright 2013 Zuza Software Foundation
+# Copyright 2013, 2016 Zuza Software Foundation
 #
 # This file is part of the Translate Toolkit.
 #
@@ -33,4 +32,6 @@ class my(common.Common):
         u".": u"။",
     }
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        'all': ["simplecaps", "startcaps"],
+    }
