@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
@@ -46,7 +45,9 @@ class nqo(common.Common):
         u"!": u"߹",
     }
 
-    ignoretests = ["startcaps", "simplecaps", "acronyms"]
+    ignoretests = {
+        'all': ["acronyms", "simplecaps", "startcaps"],
+    }
 
     @classmethod
     def punctranslate(cls, text):
