@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
@@ -29,6 +28,8 @@ from translate.lang import common
 class sv(common.Common):
     """This class represents Swedish."""
 
-    validaccel = u"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
-                 u"1234567890" + \
-                 u"åäöÅÄÖ"
+    validaccel = (u"abcdefghijklmnopqrstuvwxyz"
+                  u"ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+                  u"1234567890"
+                  u"åäö"
+                  u"ÅÄÖ")
