@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
@@ -21,24 +21,27 @@
 """Module to guess the language ISO code based on the 'Language-Team' entry in
 the header of a Gettext PO file.
 """
+from __future__ import print_function
 
 import re
 
+import six
 
-__all__ = ['LANG_TEAM_CONTACT_SNIPPETS', 'guess_language']
+
+__all__ = ('LANG_TEAM_CONTACT_SNIPPETS', 'guess_language')
 
 LANG_TEAM_REGEX = (
-   ("@li.org", "([a-z_A-Z]{2,})@li.org", ["LL", "XX", "TEAM"]),
-   ("translation-team",
-    "translation-team-([a-z_A-Z]+)@lists.sourceforge.net", None),
-   ("fedora-trans", "fedora-trans-([a-z_A-Z]+)@redhat.com", ["list"]),
-   ("ubuntu-l10n", "ubuntu-l10n-([a-z_A-Z]+)@lists.ubuntu.com", None),
-   ("translate-discuss",
-    "translate-discuss-([a-z_A-Z]+)@lists.sourceforge.net", None),
-   ("kde-i18n", "kde-i18n-([a-z_A-Z]+)@(?:lists\.|mail\.|)kde.org", ["doc"]),
-   ("kde-l10n", "kde-l10n-([a-z_A-Z]+)@kde.org", None),
-   ("fedoraproject", "trans-([a-z_A-Z]+)@lists.fedoraproject.org", None),
-   ("gnome.org", "gnome-([a-z_A-Z]+)-list@gnome.org", ["latin"]),
+    ("@li.org", "([a-z_A-Z]{2,})@li.org", ["LL", "XX", "TEAM"]),
+    ("translation-team",
+     "translation-team-([a-z_A-Z]+)@lists.sourceforge.net", None),
+    ("fedora-trans", "fedora-trans-([a-z_A-Z]+)@redhat.com", ["list"]),
+    ("ubuntu-l10n", "ubuntu-l10n-([a-z_A-Z]+)@lists.ubuntu.com", None),
+    ("translate-discuss",
+     "translate-discuss-([a-z_A-Z]+)@lists.sourceforge.net", None),
+    ("kde-i18n", "kde-i18n-([a-z_A-Z]+)@(?:lists\.|mail\.|)kde.org", ["doc"]),
+    ("kde-l10n", "kde-l10n-([a-z_A-Z]+)@kde.org", None),
+    ("fedoraproject", "trans-([a-z_A-Z]+)@lists.fedoraproject.org", None),
+    ("gnome.org", "gnome-([a-z_A-Z]+)-list@gnome.org", ["latin"]),
 )
 """Data for regular expression based extraction.  The fieds are: prefilter
 information, regex with single group that contains the language code,
@@ -402,7 +405,7 @@ def _snippet_guesser(snippets_dict, string, filter_=_nofilter):
     before examination
     """
     string = filter_(string)
-    for possible_lang, snippets in snippets_dict.iteritems():
+    for possible_lang, snippets in six.iteritems(snippets_dict):
         for snippet in snippets:
             if filter_(snippet) in string:
                 return possible_lang
@@ -431,6 +434,7 @@ def guess_language(team_string):
         return None
     return lang
 
+
 if __name__ == "__main__":
     from sys import argv
     from translate.storage import factory
