@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
@@ -36,4 +35,6 @@ class th(common.Common):
 
     # No capitalisation. While we can't do sentence segmentation, sentencecount
     # is useless.
-    ignoretests = ["startcaps", "simplecaps", "sentencecount"]
+    ignoretests = {
+        'all': ["sentencecount", "simplecaps", "startcaps"],
+    }
