@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2012 Michal Čihař
@@ -22,8 +21,9 @@
 """Module for handling Android String and Plurals resource files."""
 
 import copy
-import re
 import os
+import re
+import six
 
 from lxml import etree
 
@@ -31,13 +31,14 @@ from translate.lang import data
 from translate.storage import base, lisa
 from translate.misc.multistring import multistring
 
-from babel.core import Locale
+from babel.core import Locale, UnknownLocaleError
 
 EOF = None
-WHITESPACE = ' \n\t'  # Whitespace that we collapse.
-MULTIWHITESPACE = re.compile('[ \n\t]{2}')
+WHITESPACE = ' \t'  # Whitespace that we collapse.
+MULTIWHITESPACE = re.compile('[ \t]{2}')
 
 
+@six.python_2_unicode_compatible
 class AndroidResourceUnit(base.TranslationUnit):
     """A single entry in the Android String resource file."""
 
@@ -81,12 +82,12 @@ class AndroidResourceUnit(base.TranslationUnit):
         return self.xmlelement.get("name")
 
     def unescape(self, text):
-        '''
+        """
         Remove escaping from Android resource.
 
         Code stolen from android2po
         <https://github.com/miracle2k/android2po>
-        '''
+        """
         # Return text for empty elements
         if text is None:
             return ''
@@ -117,7 +118,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                     if not active_quote or c is EOF:
                         # Replace by a single space, will get rid of
                         # non-significant newlines/tabs etc.
-                        text[i-space_count : i] = ' '
+                        text[i-space_count:i] = ' '
                         i -= space_count - 1
                     space_count = 0
                 elif space_count == 1:
@@ -167,16 +168,16 @@ class AndroidResourceUnit(base.TranslationUnit):
                         # in the clauses below without issue.
                         pass
                     elif c == 'n' or c == 'N':
-                        text[i-1 : i+1] = '\n'  # an actual newline
+                        text[i-1:i+1] = '\n'  # an actual newline
                         i -= 1
                     elif c == 't' or c == 'T':
-                        text[i-1 : i+1] = '\t'  # an actual tab
+                        text[i-1:i+1] = '\t'  # an actual tab
                         i -= 1
                     elif c == ' ':
-                        text[i-1 : i+1] = ' '  # an actual space
+                        text[i-1:i+1] = ' '  # an actual space
                         i -= 1
                     elif c in '"\'@':
-                        text[i-1 : i] = ''  # remove the backslash
+                        text[i-1:i] = ''  # remove the backslash
                         i -= 1
                     elif c == 'u':
                         # Unicode sequence. Android is nice enough to deal
@@ -190,7 +191,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                         # Note: max(len()) is needed in the slice due to
                         # trailing ``None`` element.
                         max_slice = min(i+5, len(text)-1)
-                        codepoint_str = "".join(text[i+1 : max_slice])
+                        codepoint_str = "".join(text[i+1:max_slice])
                         if len(codepoint_str) < 4:
                             codepoint_str = u"0" * (4-len(codepoint_str)) + codepoint_str
                         try:
@@ -198,15 +199,15 @@ class AndroidResourceUnit(base.TranslationUnit):
                             # it will ignore leading/trailing whitespace.
                             if not codepoint_str.isalnum():
                                 raise ValueError(codepoint_str)
-                            codepoint = unichr(int(codepoint_str, 16))
+                            codepoint = six.unichr(int(codepoint_str, 16))
                         except ValueError:
                             raise ValueError('bad unicode escape sequence')
 
-                        text[i-1 : max_slice] = codepoint
+                        text[i-1:max_slice] = codepoint
                         i -= 1
                     else:
                         # All others, remove, like Android does as well.
-                        text[i-1 : i+1] = ''
+                        text[i-1:i+1] = ''
                         i -= 1
                     active_escape = False
 
@@ -229,10 +230,6 @@ class AndroidResourceUnit(base.TranslationUnit):
         if len(text) == 0:
             return ''
         text = text.replace('\\', '\\\\')
-        text = text.replace('\n', '\\n')
-        # This will add non intrusive real newlines to
-        # ones in translation improving readability of result
-        text = text.replace(' \\n', '\n\\n')
         text = text.replace('\t', '\\t')
         text = text.replace('\'', '\\\'')
         text = text.replace('"', '\\"')
@@ -262,7 +259,7 @@ class AndroidResourceUnit(base.TranslationUnit):
             try:
                 # Try to handle it as legacy XML
                 newstring = etree.fromstring('<string>%s</string>' % target)
-            except:
+            except Exception:
                 # Fallback to string with XML escaping
                 xmltarget.text = self.escape(target)
             else:
@@ -297,7 +294,10 @@ class AndroidResourceUnit(base.TranslationUnit):
                 self.xmlelement.tail = '\n'
                 self.setid(old_id)
 
-            lang_tags = set(Locale(self.gettargetlanguage()).plural_form.tags)
+            try:
+                lang_tags = set(Locale(self.gettargetlanguage()).plural_form.tags)
+            except UnknownLocaleError:
+                lang_tags = set(Locale('en').plural_form.tags)
             # Ensure that the implicit default "other" rule is present (usually omitted by Babel)
             lang_tags.add('other')
 
@@ -392,8 +392,9 @@ class AndroidResourceUnit(base.TranslationUnit):
         if origin in ['programmer', 'developer', 'source code', None]:
             self.xmlelement.addprevious(etree.Comment(text))
         else:
-            return super(AndroidResourceUnit, self).addnote(text, origin=origin,
-                                                 position=position)
+            return super(AndroidResourceUnit, self).addnote(text,
+                                                            origin=origin,
+                                                            position=position)
 
     def getnotes(self, origin=None):
         if origin in ['programmer', 'developer', 'source code', None]:
@@ -419,7 +420,7 @@ class AndroidResourceUnit(base.TranslationUnit):
 
     def __str__(self):
         return etree.tostring(self.xmlelement, pretty_print=True,
-                              encoding='utf-8')
+                              encoding='unicode')
 
     def __eq__(self, other):
         return (str(self) == str(other))
@@ -434,6 +435,7 @@ class AndroidResourceUnit(base.TranslationUnit):
 
 class AndroidResourceFile(lisa.LISAfile):
     """Class representing an Android String resource file store."""
+
     UnitClass = AndroidResourceUnit
     Name = "Android String Resource"
     Mimetypes = ["application/xml"]
@@ -444,8 +446,9 @@ class AndroidResourceFile(lisa.LISAfile):
 <resources></resources>'''
 
     def initbody(self):
-        """Initialises self.body so it never needs to be retrieved from the
-        XML again."""
+        """Initialises self.body so it never needs to be retrieved from the XML
+        again.
+        """
         self.namespace = self.document.getroot().nsmap.get(None, None)
         self.body = self.document.getroot()
 
@@ -486,3 +489,24 @@ class AndroidResourceFile(lisa.LISAfile):
             self.settargetlanguage(target_lang)
 
         return target_lang
+
+    def addunit(self, unit, new=True):
+        """Adds unit to the document
+
+        In addition to the standard addunit, it also tries to move
+        namespace definitions to the top <resources> element.
+        """
+        newns = {}
+        do_cleanup = False
+        if new:
+            newns = self.body.nsmap
+            for ns in unit.xmlelement.nsmap:
+                if ns not in newns:
+                    do_cleanup = True
+                    newns[ns] = unit.xmlelement.nsmap[ns]
+
+        super(AndroidResourceFile, self).addunit(unit, new)
+        # Move aliased namespaces to the <resources> tag
+        # The top_nsmap was introduced in LXML 3.5.0
+        if do_cleanup:
+            etree.cleanup_namespaces(self.body, top_nsmap=newns)
