@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2002-2013 Zuza Software Foundation
@@ -85,14 +84,16 @@ Escaping in Android DTD
 """
 
 import re
+import six
 import warnings
-from cStringIO import StringIO
+from io import BytesIO
 try:
     from lxml import etree
 except ImportError:
     etree = None
 
 from translate.misc import quote
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
@@ -105,7 +106,7 @@ ending in :attr:`.labelsuffixes` into accelerator notation"""
 
 
 def quoteforandroid(source):
-    """Escapes a line for Android DTD files. """
+    """Escapes a line for Android DTD files."""
     # Replace "'" character with the \u0027 escape. Other possible replaces are
     # "\\&apos;" or "\\'".
     source = source.replace(u"'", u"\\u0027")
@@ -127,10 +128,11 @@ def unquotefromandroid(source):
 _DTD_CODEPOINT2NAME = {
     ord("%"): "#037",  # Always escape % sign as &#037;.
     ord("&"): "amp",
-   #ord("<"): "lt",  # Not really so useful.
-   #ord(">"): "gt",  # Not really so useful.
+    #ord("<"): "lt",  # Not really so useful.
+    #ord(">"): "gt",  # Not really so useful.
 }
 
+
 def quotefordtd(source):
     """Quotes and escapes a line for regular DTD files."""
     source = quote.entityencode(source, _DTD_CODEPOINT2NAME)
@@ -143,22 +145,23 @@ def quotefordtd(source):
             value = "'" + source + "'"  # Quote using single quotes.
     else:
         value = "\"" + source + "\""  # Quote using double quotes.
-    return value.encode('utf-8')
+    return value
 
 
 _DTD_NAME2CODEPOINT = {
-    "quot":   ord('"'),
-    "amp":    ord("&"),
-   #"lt":     ord("<"),  # Not really so useful.
-   #"gt":     ord(">"),  # Not really so useful.
-   # FIXME these should probably be handled in a more general way
+    "quot": ord('"'),
+    "amp": ord("&"),
+    #"lt": ord("<"),  # Not really so useful.
+    #"gt": ord(">"),  # Not really so useful.
+    # FIXME these should probably be handled in a more general way
     "#x0022": ord('"'),
-    "#187":   ord(u"»"),
-    "#037":   ord("%"),
-    "#37":    ord("%"),
-    "#x25":   ord("%"),
+    "#187": ord(u"»"),
+    "#037": ord("%"),
+    "#37": ord("%"),
+    "#x25": ord("%"),
 }
 
+
 def unquotefromdtd(source):
     """unquotes a quoted dtd definition"""
     # extract the string, get rid of quoting
@@ -168,7 +171,8 @@ def unquotefromdtd(source):
     # string. Of course there could also be quote characters within the string.
     quotechar = source[0]
     extracted, quotefinished = quote.extractwithoutquotes(source, quotechar, quotechar, allowreentry=False)
-    extracted = extracted.decode('utf-8')
+    if isinstance(extracted, bytes):
+        extracted = extracted.decode('utf-8')
     if quotechar == "'":
         extracted = extracted.replace("&apos;", "'")
     extracted = quote.entitydecode(extracted, _DTD_NAME2CODEPOINT)
@@ -221,6 +225,7 @@ def removeinvalidamps(name, value):
     return value
 
 
+@six.python_2_unicode_compatible
 class dtdunit(base.TranslationUnit):
     """An entity definition from a DTD file (and any associated comments)."""
 
@@ -323,7 +328,6 @@ class dtdunit(base.TranslationUnit):
         for line in lines:
             line += "\n"
             linesprocessed += 1
-            # print "line(%d,%d): " % (self.incomment,self.inentity),line[:-1]
             if not self.incomment:
                 if (line.find('<!--') != -1):
                     self.incomment = True
@@ -355,7 +359,6 @@ class dtdunit(base.TranslationUnit):
             if self.incomment:
                 # some kind of comment
                 (comment, self.incomment) = quote.extract(line, "<!--", "-->", None, self.continuecomment)
-                # print "comment(%d,%d): " % (self.incomment,self.continuecomment),comment
                 self.continuecomment = self.incomment
                 # strip the comment out of what will be parsed
                 line = line.replace(comment, "", 1)
@@ -481,21 +484,11 @@ class dtdunit(base.TranslationUnit):
                         self.inentity = False
                         break
 
-        # uncomment this line to debug processing
-        if 0:
-            for attr in dir(self):
-                r = repr(getattr(self, attr))
-                if len(r) > 60:
-                    r = r[:57] + "..."
-                self.comments.append(("comment", "self.%s = %s" % (attr, r)))
         return linesprocessed
 
     def __str__(self):
-        """convert to a string. double check that unicode is handled somehow here"""
-        source = self.getoutput()
-        if isinstance(source, unicode):
-            return source.encode(getattr(self, "encoding", "UTF-8"))
-        return source
+        """convert to a string."""
+        return self.getoutput()
 
     def getoutput(self):
         """convert the dtd entity back to string form"""
@@ -516,19 +509,18 @@ class dtdunit(base.TranslationUnit):
                 entityline = '<!ENTITY' + self.space_pre_entity + self.entity + self.space_pre_definition + self.definition + self.closing
             if getattr(self, 'hashprefix', None):
                 entityline = self.hashprefix + " " + entityline
-            if isinstance(entityline, unicode):
-                entityline = entityline.encode('UTF-8')
             lines.append(entityline + '\n')
         return "".join(lines)
 
 
 class dtdfile(base.TranslationStore):
     """A .dtd file made up of dtdunits."""
+
     UnitClass = dtdunit
 
     def __init__(self, inputfile=None, android=False):
         """construct a dtdfile, optionally reading in from inputfile"""
-        base.TranslationStore.__init__(self, unitclass=self.UnitClass)
+        super(dtdfile, self).__init__()
         self.filename = getattr(inputfile, 'name', '')
         self.android = android
         if inputfile is not None:
@@ -540,7 +532,7 @@ class dtdfile(base.TranslationStore):
         """read the source code of a dtd file in and include them as dtdunits in self.units"""
         start = 0
         end = 0
-        lines = dtdsrc.split("\n")
+        lines = dtdsrc.split(b"\n")
         while end < len(lines):
             if (start == end):
                 end += 1
@@ -548,39 +540,39 @@ class dtdfile(base.TranslationStore):
             while end < len(lines):
                 if end >= len(lines):
                     break
-                if lines[end].find('<!ENTITY') > -1:
+                if lines[end].find(b'<!ENTITY') > -1:
                     foundentity = True
-                if foundentity and re.match("[\"']\s*>", lines[end]):
+                if foundentity and re.match(b"[\"']\s*>", lines[end]):
                     end += 1
                     break
                 end += 1
-            # print "processing from %d to %d" % (start,end)
 
             linesprocessed = 1  # to initialise loop
             while linesprocessed >= 1:
                 newdtd = dtdunit(android=self.android)
                 try:
-                    linesprocessed = newdtd.parse("\n".join(lines[start:end]))
+                    linesprocessed = newdtd.parse((b"\n".join(lines[start:end])).decode(self.encoding))
                     if linesprocessed >= 1 and (not newdtd.isnull() or newdtd.unparsedlines):
                         self.units.append(newdtd)
                 except Exception as e:
-                    warnings.warn("%s\nError occured between lines %d and %d:\n%s" % (e, start + 1, end, "\n".join(lines[start:end])))
+                    warnings.warn("%s\nError occured between lines %d and %d:\n%s" % (e, start + 1, end, b"\n".join(lines[start:end])))
                 start += linesprocessed
 
-    def __str__(self):
-        """convert to a string. double check that unicode is handled somehow here"""
-        source = self.getoutput()
-        if not self._valid_store():
+    def serialize(self, out):
+        """Write content to file"""
+        content = b''
+        for dtd in self.units:
+            unit_str = six.text_type(dtd).encode(self.encoding)
+            out.write(unit_str)
+            content += unit_str
+        if not self._valid_store(content):
             warnings.warn("DTD file '%s' does not validate" % self.filename)
-            return None
-        if isinstance(source, unicode):
-            return source.encode(getattr(self, "encoding", "UTF-8"))
-        return source
+            out.truncate(0)
 
+    # Deprecated on 2.0.0
+    @deprecated("Use bytes(dtdfile) instead")
     def getoutput(self):
-        """convert the units back to source"""
-        sources = [str(dtd) for dtd in self.units]
-        return "".join(sources)
+        return bytes(self)
 
     def makeindex(self):
         """makes self.id_index dictionary keyed on entities"""
@@ -589,7 +581,7 @@ class dtdfile(base.TranslationStore):
             if not dtd.isnull():
                 self.id_index[dtd.entity] = dtd
 
-    def _valid_store(self):
+    def _valid_store(self, content):
         """Validate the store to determine if it is valid
 
         This uses ElementTree to parse the DTD
@@ -599,9 +591,10 @@ class dtdfile(base.TranslationStore):
         """
         # Android files are invalid DTDs
         if etree is not None and not self.android:
+            # #expand is a Mozilla hack and are removed as they are not valid in DTDs
+            _input = re.sub(b"#expand", b"", content)
             try:
-                # #expand is a Mozilla hack and are removed as they are not valid in DTDs
-                dtd = etree.DTD(StringIO(re.sub("#expand", "", self.getoutput())))
+                dtd = etree.DTD(BytesIO(_input))
             except etree.DTDParseError as e:
                 warnings.warn("DTD parse error: %s" % e.error_log)
                 return False
