@@ -170,7 +170,7 @@ class OmegaTFile(base.TranslationStore):
             input = tmsrc
         try:
             input = input.decode(self.encoding)
-        except:
+        except Exception:
             raise ValueError("OmegaT files are either UTF-8 encoded or use the default system encoding")
         lines = csv.DictReader(input.split("\n"), fieldnames=OMEGAT_FIELDNAMES,
                                dialect="omegat")
