@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2006-2009 Zuza Software Foundation
@@ -25,10 +24,12 @@ This way the API supports plurals as if it was a PO file, for example.
 """
 
 import re
+import six
 
 from lxml import etree
 
 from translate.misc.multistring import multistring
+from translate.misc.xml_helpers import setXMLspace
 from translate.storage import base, lisa, poheader, xliff
 from translate.storage.placeables import general
 
@@ -44,7 +45,7 @@ class PoXliffUnit(xliff.xliffunit):
 
     rich_parsers = general.parsers
 
-    def __init__(self, source=None, empty=False, encoding="UTF-8"):
+    def __init__(self, source=None, empty=False, **kwargs):
         self._rich_source = None
         self._rich_target = None
         self._state_n = 0
@@ -59,7 +60,7 @@ class PoXliffUnit(xliff.xliffunit):
 
         self.xmlelement = etree.Element(self.namespaced("group"))
         self.xmlelement.set("restype", "x-gettext-plurals")
-        self.setsource(source)
+        self.source = source
 
     def __eq__(self, other):
         if isinstance(other, PoXliffUnit):
@@ -95,7 +96,7 @@ class PoXliffUnit(xliff.xliffunit):
             for unit in self.units:
                 try:
                     self.xmlelement.remove(unit.xmlelement)
-                except xml.dom.NotFoundErr:
+                except ValueError:
                     pass
             self.units = []
             for s in source.strings:
@@ -123,7 +124,7 @@ class PoXliffUnit(xliff.xliffunit):
 
     def settarget(self, text, lang='xx', append=False):
         self._rich_target = None
-        if self.gettarget() == text:
+        if self.target == text:
             return
         if not self.hasplural():
             super(PoXliffUnit, self).settarget(text, lang, append)
@@ -161,7 +162,7 @@ class PoXliffUnit(xliff.xliffunit):
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in a "note" tag"""
-        if isinstance(text, str):
+        if isinstance(text, bytes):
             text = text.decode("utf-8")
         note = etree.SubElement(self.xmlelement, self.namespaced("note"))
         note.text = text
@@ -230,10 +231,11 @@ class PoXliffUnit(xliff.xliffunit):
 
     def getautomaticcomments(self):
         """Returns the automatic comments (x-po-autocomment), which corresponds
-        to the #. style po comments."""
+        to the #. style po comments.
+        """
 
-        def hasautocomment((type, text)):
-            return type == "x-po-autocomment"
+        def hasautocomment(grp):
+            return grp[0] == "x-po-autocomment"
         groups = self.getcontextgroups("po-entry")
         comments = []
         for group in groups:
@@ -243,11 +245,12 @@ class PoXliffUnit(xliff.xliffunit):
         return "\n".join(comments)
 
     def gettranslatorcomments(self):
-        """Returns the translator comments (x-po-trancomment), which corresponds
-        to the # style po comments."""
+        """Returns the translator comments (x-po-trancomment), which
+        corresponds to the # style po comments.
+        """
 
-        def hastrancomment((type, text)):
-            return type == "x-po-trancomment"
+        def hastrancomment(grp):
+            return grp[0] == "x-po-trancomment"
         groups = self.getcontextgroups("po-entry")
         comments = []
         for group in groups:
@@ -286,10 +289,11 @@ class PoXliffUnit(xliff.xliffunit):
 
 class PoXliffFile(xliff.xlifffile, poheader.poheader):
     """a file for the po variant of Xliff files"""
+
     UnitClass = PoXliffUnit
 
     def __init__(self, *args, **kwargs):
-        if not "sourcelanguage" in kwargs:
+        if "sourcelanguage" not in kwargs:
             kwargs["sourcelanguage"] = "en-US"
         xliff.xlifffile.__init__(self, *args, **kwargs)
 
@@ -301,7 +305,7 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
     def _insert_header(self, header):
         header.xmlelement.set("restype", "x-gettext-domain-header")
         header.xmlelement.set("approved", "no")
-        lisa.setXMLspace(header.xmlelement, "preserve")
+        setXMLspace(header.xmlelement, "preserve")
         self.addunit(header)
 
     def addheaderunit(self, target, filename):
@@ -309,7 +313,7 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
         unit.target = target
         unit.xmlelement.set("restype", "x-gettext-domain-header")
         unit.xmlelement.set("approved", "no")
-        lisa.setXMLspace(unit.xmlelement, "preserve")
+        setXMLspace(unit.xmlelement, "preserve")
         return unit
 
     def addplural(self, source, target, filename, createifmissing=False):
@@ -380,22 +384,16 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
         pluralgroups = filter(ispluralgroup, groups)
         termEntries = root_node.iterdescendants(self.namespaced(self.UnitClass.rootNode))
 
-        singularunits = filter(isnonpluralunit, termEntries)
+        singularunits = list(filter(isnonpluralunit, termEntries))
         if len(singularunits) == 0:
             return
         pluralunit_iter = pluralunits(pluralgroups)
-        try:
-            nextplural = pluralunit_iter.next()
-        except StopIteration:
-            nextplural = None
+        nextplural = next(pluralunit_iter, None)
 
         for entry in singularunits:
             term = self.UnitClass.createfromxmlElement(entry, namespace=self.namespace)
-            if nextplural and unicode(term.getid()) == ("%s[0]" % nextplural.getid()):
+            if nextplural and six.text_type(term.getid()) == ("%s[0]" % nextplural.getid()):
                 self.addunit(nextplural, new=False)
-                try:
-                    nextplural = pluralunit_iter.next()
-                except StopIteration as i:
-                    nextplural = None
+                nextplural = next(pluralunit_iter, None)
             else:
                 self.addunit(term, new=False)
