@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2015 Zuza Software Foundation
@@ -24,9 +23,11 @@
 from lxml import etree
 
 from translate.lang import data
+from translate.misc.xml_helpers import setXMLspace
 from translate.storage import base, lisa
 from translate.storage.placeables import general
 
+
 class RESXUnit(lisa.LISAunit):
     """A single term in the RESX file."""
 
@@ -48,13 +49,13 @@ class RESXUnit(lisa.LISAunit):
         return self.xmlelement.find(self.namespaced(self.languageNode))
 
     def getsource(self):
-        return self.gettarget()
+        return self.target
 
     def settarget(self, text, lang='xx', append=False):
         # Firstly deal with reinitialising to None or setting to identical
         # string.
         self._rich_target = None
-        if self.gettarget() == text:
+        if self.target == text:
             return
         strings = []
         if isinstance(text, list):
@@ -77,7 +78,7 @@ class RESXUnit(lisa.LISAunit):
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in the appropriate "comment" tag"""
-        if isinstance(text, str):
+        if isinstance(text, bytes):
             text = text.decode("utf-8")
         current_notes = self.getnotes(origin)
         self.removenotes(origin)
@@ -101,7 +102,7 @@ class RESXUnit(lisa.LISAunit):
 
     def removenotes(self, origin=None):
         note = self.xmlelement.find(self.namespaced("comment"))
-        if not note is None:
+        if note is not None:
             self.xmlelement.remove(note)
 
     def setid(self, value):
@@ -124,6 +125,7 @@ class RESXUnit(lisa.LISAunit):
 
 class RESXFile(lisa.LISAfile):
     """Class representing a RESX file store."""
+
     UnitClass = RESXUnit
     Name = ".NET RESX File"
     Mimetypes = ["text/microsoft-resx"]
@@ -202,7 +204,7 @@ class RESXFile(lisa.LISAfile):
     def addunit(self, unit, new=True):
         """Adds the given unit to the body node."""
         super(RESXFile, self).addunit(unit, new)
-        lisa.setXMLspace(unit.xmlelement, "preserve")
+        setXMLspace(unit.xmlelement, "preserve")
         if unit.getid() is None:
             self._messagenum += 1
             unit.setid(u"%s" % unit.source.strip(' '))
