@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
 from pytest import mark
@@ -100,7 +99,7 @@ class TestPhpFile(test_monolingual.TestMonolingualStore):
 
     def phpregen(self, phpsource):
         """helper that converts php source to phpfile object and back"""
-        return str(self.phpparse(phpsource))
+        return bytes(self.phpparse(phpsource)).decode('utf-8')
 
     def test_simpledefinition(self):
         """checks that a simple php definition is parsed correctly"""
