@@ -1,56 +1,51 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-from pytest import deprecated_call, raises
+from pytest import raises
 
 from translate.misc import wStringIO
 from translate.storage import properties, test_monolingual
 
 
+# Note that DialectJava delimitors are [u"=", u":", u" "]
+
 def test_find_delimiter_pos_simple():
     """Simple tests to find the various delimiters"""
-    assert properties._find_delimiter(u"key=value", [u"=", u":", u" "]) == ('=', 3)
-    assert properties._find_delimiter(u"key:value", [u"=", u":", u" "]) == (':', 3)
-    assert properties._find_delimiter(u"key value", [u"=", u":", u" "]) == (' ', 3)
+    assert properties.DialectJava.find_delimiter(u"key=value") == ('=', 3)
+    assert properties.DialectJava.find_delimiter(u"key:value") == (':', 3)
+    assert properties.DialectJava.find_delimiter(u"key value") == (' ', 3)
     # NOTE this is valid in Java properties, the key is then the empty string
-    assert properties._find_delimiter(u"= value", [u"=", u":", u" "]) == ('=', 0)
+    assert properties.DialectJava.find_delimiter(u"= value") == ('=', 0)
 
 
 def test_find_delimiter_pos_multiple():
     """Find delimiters when multiple potential delimiters are involved"""
-    assert properties._find_delimiter(u"key=value:value", [u"=", u":", u" "]) == ('=', 3)
-    assert properties._find_delimiter(u"key:value=value", [u"=", u":", u" "]) == (':', 3)
-    assert properties._find_delimiter(u"key value=value", [u"=", u":", u" "]) == (' ', 3)
+    assert properties.DialectJava.find_delimiter(u"key=value:value") == ('=', 3)
+    assert properties.DialectJava.find_delimiter(u"key:value=value") == (':', 3)
+    assert properties.DialectJava.find_delimiter(u"key value=value") == (' ', 3)
 
 
 def test_find_delimiter_pos_none():
     """Find delimiters when there isn't one"""
-    assert properties._find_delimiter(u"key", [u"=", u":", u" "]) == (None, -1)
-    assert properties._find_delimiter(u"key\=\:\ ", [u"=", u":", u" "]) == (None, -1)
+    assert properties.DialectJava.find_delimiter(u"key") == (None, -1)
+    assert properties.DialectJava.find_delimiter(u"key\=\:\ ") == (None, -1)
 
 
 def test_find_delimiter_pos_whitespace():
     """Find delimiters when whitespace is involved"""
-    assert properties._find_delimiter(u"key = value", [u"=", u":", u" "]) == ('=', 4)
-    assert properties._find_delimiter(u"key : value", [u"=", u":", u" "]) == (':', 4)
-    assert properties._find_delimiter(u"key   value", [u"=", u":", u" "]) == (' ', 3)
-    assert properties._find_delimiter(u"key value = value", [u"=", u":", u" "]) == (' ', 3)
-    assert properties._find_delimiter(u"key value value", [u"=", u":", u" "]) == (' ', 3)
-    assert properties._find_delimiter(u" key = value", [u"=", u":", u" "]) == ('=', 5)
+    assert properties.DialectJava.find_delimiter(u"key = value") == ('=', 4)
+    assert properties.DialectJava.find_delimiter(u"key : value") == (':', 4)
+    assert properties.DialectJava.find_delimiter(u"key   value") == (' ', 3)
+    assert properties.DialectJava.find_delimiter(u"key value = value") == (' ', 3)
+    assert properties.DialectJava.find_delimiter(u"key value value") == (' ', 3)
+    assert properties.DialectJava.find_delimiter(u" key = value") == ('=', 5)
 
 
 def test_find_delimiter_pos_escapes():
     """Find delimiters when potential earlier delimiters are escaped"""
-    assert properties._find_delimiter(u"key\:=value", [u"=", u":", u" "]) == ('=', 5)
-    assert properties._find_delimiter(u"key\=: value", [u"=", u":", u" "]) == (':', 5)
-    assert properties._find_delimiter(u"key\   value", [u"=", u":", u" "]) == (' ', 5)
-    assert properties._find_delimiter(u"key\ key\ key\: = value", [u"=", u":", u" "]) == ('=', 16)
-
-
-def test_find_delimiter_deprecated_fn():
-    """Test that the deprecated function still actually works"""
-    assert properties.find_delimeter(u"key=value") == ('=', 3)
-    deprecated_call(properties.find_delimeter, u"key=value")
+    assert properties.DialectJava.find_delimiter(u"key\:=value") == ('=', 5)
+    assert properties.DialectJava.find_delimiter(u"key\=: value") == (':', 5)
+    assert properties.DialectJava.find_delimiter(u"key\   value") == (' ', 5)
+    assert properties.DialectJava.find_delimiter(u"key\ key\ key\: = value") == ('=', 16)
 
 
 def test_is_line_continuation():
@@ -109,9 +104,9 @@ class TestProp(test_monolingual.TestMonolingualStore):
         propfile = properties.propfile(dummyfile, personality, encoding)
         return propfile
 
-    def propregen(self, propsource):
+    def propregen(self, propsource, encoding=None):
         """helper that converts properties source to propfile object and back"""
-        return str(self.propparse(propsource))
+        return bytes(self.propparse(propsource, encoding=encoding)).decode('utf-8')
 
     def test_simpledefinition(self):
         """checks that a simple properties definition is parsed correctly"""
@@ -128,6 +123,18 @@ class TestProp(test_monolingual.TestMonolingualStore):
         propregen = self.propregen(propsource)
         assert propsource + '\n' == propregen
 
+    def test_controlutf8_source(self):
+        """checks that a control characters are parsed correctly"""
+        propsource = u'test_me=\\\\\\n'
+        propregen = self.propregen(propsource, encoding='utf-8')
+        assert propsource + '\n' == propregen
+
+    def test_control_source(self):
+        """checks that a control characters are parsed correctly"""
+        propsource = 'test_me=\\\\\\n'
+        propregen = self.propregen(propsource)
+        assert propsource + '\n' == propregen
+
     def test_unicode_escaping(self):
         """check that escaped unicode is converted properly"""
         propsource = "unicode=\u0411\u0416\u0419\u0428"
@@ -136,10 +143,10 @@ class TestProp(test_monolingual.TestMonolingualStore):
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
         assert propunit.name == "unicode"
-        assert propunit.source.encode("UTF-8") == "БЖЙШ"
-        regensource = str(propfile)
+        assert propunit.source == u"БЖЙШ"
+        regensource = bytes(propfile)
         assert messagevalue in regensource
-        assert "\\u" not in regensource
+        assert b"\\u" not in regensource
 
     def test_newlines_startend(self):
         """check that we preserve \n that appear at start and end of properties"""
@@ -223,7 +230,7 @@ key=value
 
     def test_fullspec_line_continuation(self):
         """Whitespace delimiter and pre whitespace in line continuation are dropped"""
-        prop_source = ur"""fruits                           apple, banana, pear, \
+        prop_source = r"""fruits                           apple, banana, pear, \
                                   cantaloupe, watermelon, \
                                   kiwi, mango
 """
@@ -232,7 +239,7 @@ key=value
         assert len(prop_store.units) == 1
         unit = prop_store.units[0]
         print(unit)
-        assert properties._find_delimiter(prop_source, [u"=", u":", u" "]) == (' ', 6)
+        assert properties.DialectJava.find_delimiter(prop_source) == (' ', 6)
         assert unit.name == u"fruits"
         assert unit.source == u"apple, banana, pear, cantaloupe, watermelon, kiwi, mango"
 
@@ -248,51 +255,51 @@ key=value
 
     def test_mac_strings(self):
         """test various items used in Mac OS X strings files"""
-        propsource = ur'''"I am a \"key\"" = "I am a \"value\"";'''.encode('utf-16')
+        propsource = r'''"I am a \"key\"" = "I am a \"value\"";'''.encode('utf-16')
         propfile = self.propparse(propsource, personality="strings")
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
-        assert propunit.name == ur'I am a "key"'
-        assert propunit.source.encode('utf-8') == u'I am a "value"'
+        assert propunit.name == u'I am a "key"'
+        assert propunit.source == u'I am a "value"'
 
     def test_mac_strings_unicode(self):
         """Ensure we can handle Unicode"""
-        propsource = ur'''"I am a “key”" = "I am a “value”";'''.encode('utf-16')
+        propsource = u'''"I am a “key”" = "I am a “value”";'''.encode('utf-16')
         propfile = self.propparse(propsource, personality="strings")
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
-        assert propunit.name == ur'I am a “key”'
+        assert propunit.name == u'I am a “key”'
         assert propfile.personality.encode(propunit.source) == u'I am a “value”'
 
     def test_mac_strings_utf8(self):
         """Ensure we can handle Unicode"""
-        propsource = ur'''"I am a “key”" = "I am a “value”";'''.encode('utf-8')
+        propsource = u'''"I am a “key”" = "I am a “value”";'''.encode('utf-8')
         propfile = self.propparse(propsource, personality="strings-utf8")
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
-        assert propunit.name == ur'I am a “key”'
+        assert propunit.name == u'I am a “key”'
         assert propfile.personality.encode(propunit.source) == u'I am a “value”'
 
     def test_mac_strings_newlines(self):
         """test newlines \n within a strings files"""
-        propsource = ur'''"key" = "value\nvalue";'''.encode('utf-16')
+        propsource = r'''"key" = "value\nvalue";'''.encode('utf-16')
         propfile = self.propparse(propsource, personality="strings")
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
         assert propunit.name == u'key'
-        assert propunit.source.encode('utf-8') == u'value\nvalue'
-        assert propfile.personality.encode(propunit.source) == ur'value\nvalue'
+        assert propunit.source == u'value\nvalue'
+        assert propfile.personality.encode(propunit.source) == r'value\nvalue'
 
     def test_mac_strings_comments(self):
         """test .string comment types"""
-        propsource = ur'''/* Comment */
+        propsource = u'''/* Comment */
 // Comment
 "key" = "value";'''.encode('utf-16')
         propfile = self.propparse(propsource, personality="strings")
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
         assert propunit.name == u'key'
-        assert propunit.source.encode('utf-8') == u'value'
+        assert propunit.source == u'value'
         assert propunit.getnotes() == u"/* Comment */\n// Comment"
 
     def test_mac_strings_multilines_comments(self):
@@ -305,31 +312,39 @@ key=value
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
         assert propunit.name == u'key'
-        assert propunit.source.encode('utf-8') == u'value'
+        assert propunit.source == u'value'
         assert propunit.getnotes() == u"/* Foo\nBar\nBaz */"
 
     def test_mac_strings_comments_dropping(self):
         """.string generic (and unuseful) comments should be dropped"""
-        propsource = ur'''/* No comment provided by engineer. */
+        propsource = u'''/* No comment provided by engineer. */
 "key" = "value";'''.encode('utf-16')
         propfile = self.propparse(propsource, personality="strings")
         assert len(propfile.units) == 1
         propunit = propfile.units[0]
         assert propunit.name == u'key'
-        assert propunit.source.encode('utf-8') == u'value'
+        assert propunit.source == u'value'
         assert propunit.getnotes() == u""
 
     def test_mac_strings_quotes(self):
         """test that parser unescapes characters used as wrappers"""
-        propsource = ur'"key with \"quotes\"" = "value with \"quotes\"";'.encode('utf-16')
+        propsource = r'"key with \"quotes\"" = "value with \"quotes\"";'.encode('utf-16')
         propfile = self.propparse(propsource, personality="strings")
         propunit = propfile.units[0]
-        assert propunit.name == ur'key with "quotes"'
-        assert propunit.value == ur'value with "quotes"'
+        assert propunit.name == u'key with "quotes"'
+        assert propunit.value == u'value with "quotes"'
+
+    def test_mac_strings_equals(self):
+        """test that equal signs inside keys/values are not mixed with delimiter"""
+        propsource = '"key with = sign" = "value with = sign";'.encode('utf-16')
+        propfile = self.propparse(propsource, personality="strings")
+        propunit = propfile.units[0]
+        assert propunit.name == u'key with = sign'
+        assert propunit.value == u'value with = sign'
 
     def test_mac_strings_serialization(self):
         """test that serializer quotes mac strings properly"""
-        propsource = ur'"key with \"quotes\"" = "value with \"quotes\"";'.encode('utf-16')
+        propsource = r'"key with \"quotes\"" = "value with \"quotes\"";'.encode('utf-16')
         propfile = self.propparse(propsource, personality="strings")
         # we don't care about leading and trailing newlines and zero bytes
         # in the assert, we just want to make sure that
@@ -337,8 +352,7 @@ key=value
         # - quotes inside are escaped
         # - for the sake of beauty a pair of spaces encloses the equal mark
         # - every line ends with ";"
-        assert str(propfile.units[0]).strip('\n\x00') == propsource.strip('\n\x00')
-        assert str(propfile).strip('\n\x00') == propsource.strip('\n\x00')
+        assert bytes(propfile).strip(b'\n\x00') == propsource.strip(b'\n\x00')
 
     def test_override_encoding(self):
         """test that we can override the encoding of a properties file"""
@@ -363,7 +377,7 @@ key=value
         """test that BOM appears in the resulting text once only"""
         propsource = u"key1 = value1\nkey2 = value2\n".encode('utf-16')
         propfile = self.propparse(propsource, encoding='utf-16')
-        result = str(propfile)
+        result = bytes(propfile)
         bom = propsource[:2]
         assert result.startswith(bom)
         assert bom not in result[2:]
@@ -373,3 +387,23 @@ key=value
         propsource = u"key = ąćęłńóśźż".encode("cp1250")
         with raises(IOError):
             self.propparse(propsource, personality="strings")
+
+    def test_utf8_byte_order_mark(self):
+        """test that BOM handling works fine with newlines"""
+        propsource = u"\n\n\nkey1 = value1\n\nkey2 = value2\n".encode('utf-8-sig')
+        propfile = self.propparse(propsource, personality='java-utf8')
+        bom = propsource[:3]
+        result = bytes(propfile)
+        assert result.startswith(bom)
+        assert bom not in result[3:]
+        assert b'None' not in result[3:]
+
+    def test_joomla(self):
+        """test various items used in Joomla files"""
+        propsource = '''; comment\nVALUE="I am a "_QQ_"value"_QQ_""\n'''.encode('utf-8')
+        propfile = self.propparse(propsource, personality="joomla")
+        assert len(propfile.units) == 1
+        propunit = propfile.units[0]
+        assert propunit.name == u'VALUE'
+        assert propunit.source == u'I am a "value"'
+        assert bytes(propfile) == propsource
