@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
 import pytest
@@ -15,25 +14,25 @@ class TestQtFile(test_base.TestTranslationStore):
 
     def test_parse(self):
         # self.reparse relies on __str__ to be output and then parsed
-        # qm.py does not implement __str__ but returns u''
+        # qm.py does not implement serialization
         pass
 
     def test_save(self):
         # QM does not implement saving
         assert pytest.raises(Exception, self.StoreClass.savefile,
-                           self.StoreClass())
+                             self.StoreClass())
 
     def test_files(self):
         # QM does not implement saving
         assert pytest.raises(Exception, self.StoreClass.savefile,
-                           self.StoreClass())
+                             self.StoreClass())
 
     def test_nonascii(self):
         # QM does not implement serialising
-        assert pytest.raises(Exception, self.StoreClass.__str__,
-                           self.StoreClass())
+        assert pytest.raises(Exception, self.StoreClass.serialize,
+                             self.StoreClass())
 
     def test_add(self):
         # QM does not implement serialising
-        assert pytest.raises(Exception, self.StoreClass.__str__,
-                           self.StoreClass())
+        assert pytest.raises(Exception, self.StoreClass.serialize,
+                             self.StoreClass())
