@@ -1,5 +1,3 @@
-#!/usr/bin/env python2
-
 from translate.storage import tbx, test_base
 
 
@@ -15,8 +13,8 @@ class TestTBXfile(test_base.TestTranslationStore):
         assert tbxfile.units == []
         tbxfile.addsourceunit("Bla")
         assert len(tbxfile.units) == 1
-        newfile = tbx.tbxfile.parsestring(str(tbxfile))
-        print(str(tbxfile))
+        newfile = tbx.tbxfile.parsestring(bytes(tbxfile))
+        print(bytes(tbxfile))
         assert len(newfile.units) == 1
         assert newfile.units[0].source == "Bla"
         assert newfile.findunit("Bla").source == "Bla"
@@ -26,8 +24,8 @@ class TestTBXfile(test_base.TestTranslationStore):
         tbxfile = tbx.tbxfile()
         tbxunit = tbxfile.addsourceunit("Concept")
         tbxunit.source = "Term"
-        newfile = tbx.tbxfile.parsestring(str(tbxfile))
-        print(str(tbxfile))
+        newfile = tbx.tbxfile.parsestring(bytes(tbxfile))
+        print(bytes(tbxfile))
         assert newfile.findunit("Concept") is None
         assert newfile.findunit("Term") is not None
 
@@ -35,6 +33,6 @@ class TestTBXfile(test_base.TestTranslationStore):
         tbxfile = tbx.tbxfile()
         tbxunit = tbxfile.addsourceunit("Concept")
         tbxunit.target = "Konsep"
-        newfile = tbx.tbxfile.parsestring(str(tbxfile))
-        print(str(tbxfile))
+        newfile = tbx.tbxfile.parsestring(bytes(tbxfile))
+        print(bytes(tbxfile))
         assert newfile.findunit("Concept").target == "Konsep"
