@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2008-2011 Zuza Software Foundation
@@ -24,15 +23,16 @@ This will eventually replace the older ts.py which only supports the older
 format. While converters haven't been updated to use this module, we retain
 both.
 
-`TS file format 4.3 <http://doc.qt.digia.com/4.3/linguist-ts-file-format.html>`_,
-`4.8 <http://qt-project.org/doc/qt-4.8/linguist-ts-file-format.html>`_,
-`5.0 <http://qt-project.org/doc/qt-5.0/qtlinguist/linguist-ts-file-format.html>`_.
+`TS file format 4.3 <http://doc.qt.io/archives/4.3/linguist-ts-file-format.html>`_,
+`4.8 <http://doc.qt.io/qt-4.8/linguist-ts-file-format.html>`_,
+`5 <http://doc.qt.io/qt-5/linguist-ts-file-format.html>`_.
 `Example <http://svn.ez.no/svn/ezcomponents/trunk/Translation/docs/linguist-format.txt>`_.
 
-`Specification of the valid variable entries <http://qt-project.org/doc/qt-5.0/qtcore/qstring.html#arg>`_,
-`2 <http://qt-project.org/doc/qt-5.0/qtcore/qstring.html#arg-2>`_
+`Specification of the valid variable entries <http://doc.qt.io/qt-5/qstring.html#arg>`_,
+`2 <http://doc.qt.io/qt-5/qstring.html#arg-2>`_
 """
 
+import six
 from lxml import etree
 
 from translate.lang import data
@@ -79,10 +79,10 @@ class tsunit(lisa.LISAunit):
     S_TRANSLATED = state.UNREVIEWED
 
     statemap = {
-                "obsolete": S_OBSOLETE,
-                "unfinished": S_FUZZY,
-                "": S_TRANSLATED,
-                None: S_TRANSLATED,
+        "obsolete": S_OBSOLETE,
+        "unfinished": S_FUZZY,
+        "": S_TRANSLATED,
+        None: S_TRANSLATED,
     }
     """This maps the unit "type" attribute to state."""
 
@@ -93,7 +93,8 @@ class tsunit(lisa.LISAunit):
         S_TRANSLATED: (state.UNREVIEWED, state.MAX),
     }
 
-    statemap_r = dict((i[1], i[0]) for i in statemap.iteritems())
+    statemap_r = dict((i[1], i[0]) for i in six.iteritems(statemap))
+    _context = None
 
     def createlanguageNode(self, lang, text, purpose):
         """Returns an xml Element setup with given parameters."""
@@ -116,10 +117,7 @@ class tsunit(lisa.LISAunit):
 
     def getlanguageNodes(self):
         """We override this to get source and target nodes."""
-
-        def not_none(node):
-            return not node is None
-        return filter(not_none, [self._getsourcenode(), self._gettargetnode()])
+        return [n for n in [self._getsourcenode(), self._gettargetnode()] if n is not None]
 
     def getsource(self):
         # TODO: support <byte>. See bug 528.
@@ -139,7 +137,7 @@ class tsunit(lisa.LISAunit):
         # Firstly deal with reinitialising to None or setting to identical
         # string.
         self._rich_target = None
-        if self.gettarget() == text:
+        if self.target == text:
             return
         strings = []
         if isinstance(text, multistring):
@@ -182,7 +180,7 @@ class tsunit(lisa.LISAunit):
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in the appropriate *comment* tag"""
-        if isinstance(text, str):
+        if isinstance(text, bytes):
             text = text.decode("utf-8")
         current_notes = self.getnotes(origin)
         self.removenotes(origin)
@@ -212,11 +210,11 @@ class tsunit(lisa.LISAunit):
         """Remove all the translator notes."""
         if origin in ["programmer", "developer", "source code", None]:
             note = self.xmlelement.find(self.namespaced("extracomment"))
-            if not note is None:
+            if note is not None:
                 self.xmlelement.remove(note)
         if origin in ["translator", None]:
             note = self.xmlelement.find(self.namespaced("translatorcomment"))
-            if not note is None:
+            if note is not None:
                 self.xmlelement.remove(note)
 
     def _gettype(self):
@@ -274,12 +272,25 @@ class tsunit(lisa.LISAunit):
     def getcontextname(self):
         parent = self.xmlelement.getparent()
         if parent is None:
+            if self._context:
+                return self._context
             return None
         context = parent.find("name")
         if context is None:
             return None
         return context.text
 
+    def setcontext(self, value):
+        if value == self.getcontextname():
+            return
+        parent = self.xmlelement.getparent()
+        if parent is None:
+            self._context = value
+        # TODO: if unit is inserted to ts store
+        # it should put unit in correct context
+        # if unit is already in store it should move
+        # and adjust store as necessary
+
     def getcontext(self):
         contexts = [self.getcontextname()]
         commentnode = self.xmlelement.find(self.namespaced("comment"))
@@ -292,7 +303,7 @@ class tsunit(lisa.LISAunit):
         return '\n'.join(contexts)
 
     def addlocation(self, location):
-        if isinstance(location, str):
+        if isinstance(location, bytes):
             location = location.decode("utf-8")
         newlocation = etree.SubElement(self.xmlelement, self.namespaced("location"))
         try:
@@ -353,6 +364,7 @@ class tsunit(lisa.LISAunit):
 
 class tsfile(lisa.LISAfile):
     """Class representing a TS file store."""
+
     UnitClass = tsunit
     Name = "Qt Linguist Translation File"
     Mimetypes = ["application/x-linguist"]
@@ -445,8 +457,9 @@ class tsfile(lisa.LISAfile):
     def addunit(self, unit, new=True, contextname=None, createifmissing=True):
         """Adds the given unit to the last used body node (current context).
 
-        If the contextname is specified, switch to that context (creating it
-        if allowed by createifmissing)."""
+        If the contextname is specified, switch to that context (creating it if
+        allowed by createifmissing).
+        """
         if contextname is None:
             contextname = unit.getcontextname()
 
@@ -459,7 +472,8 @@ class tsfile(lisa.LISAfile):
 
     def _switchcontext(self, contextname, createifmissing=False):
         """Switch the current context to the one named contextname, optionally
-        creating it if it doesn't exist."""
+        creating it if it doesn't exist.
+        """
         self._contextname = contextname
         contextnode = self._getcontextnode(contextname)
         if contextnode is None:
@@ -479,13 +493,15 @@ class tsfile(lisa.LISAfile):
         else:
             return 1
 
-    def __str__(self):
-        """Converts to a string containing the file's XML."""
+    def serialize(self, out):
+        """Write the XML document to a file."""
         root = self.document.getroot()
         doctype = self.document.docinfo.doctype
         # Iterate over empty tags without children and force empty text
         # This will prevent self-closing tags in pretty_print mode
-        for e in root.xpath("//*[not(./node()) and not(text())]"):
+        # Qt Linguist does self-close the "location" elements though
+        for e in root.xpath("//*[not(./node()) and not(text()) and not(name() = 'location')]"):
             e.text = ""
-        return etree.tostring(root, doctype=doctype, pretty_print=True,
-                              xml_declaration=True, encoding='utf-8')
+        out.write(str('<?xml version="1.0" encoding="utf-8"?>\n').encode('utf-8'))
+        out.write(etree.tostring(root, doctype=doctype, pretty_print=True,
+                                 xml_declaration=None, encoding='utf-8'))
