@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # This file is part of translate.
@@ -24,7 +24,9 @@ for examples and usage instructions.
 import logging
 import os
 import re
+import six
 import sys
+from operator import itemgetter
 
 from translate.lang import factory as lang_factory
 from translate.misc import file_discovery, optrecurse
@@ -40,7 +42,7 @@ def create_termunit(term, unit, targets, locations, sourcenotes, transnotes, fil
         termunit.merge(unit, overwrite=False, comments=False)
     if len(targets.keys()) > 1:
         txt = '; '.join(["%s {%s}" % (target, ', '.join(files))
-                         for target, files in targets.iteritems()])
+                         for target, files in six.iteritems(targets)])
         if termunit.target.find('};') < 0:
             termunit.target = txt
             termunit.markfuzzy()
@@ -53,7 +55,7 @@ def create_termunit(term, unit, targets, locations, sourcenotes, transnotes, fil
         termunit.addnote(sourcenote, "developer")
     for transnote in transnotes:
         termunit.addnote(transnote, "translator")
-    for filename, count in filecounts.iteritems():
+    for filename, count in six.iteritems(filecounts):
         termunit.addnote("(poterminology) %s (%d)\n" % (filename, count), 'translator')
     return termunit
 
@@ -78,7 +80,7 @@ class TerminologyExtractor(object):
         if stopfile is None:
             try:
                 stopfile = file_discovery.get_abs_data_filename('stoplist-%s' % self.sourcelanguage)
-            except:
+            except Exception:
                 pass
         self.stopfile = stopfile
         self.parse_stopword_file()
@@ -89,7 +91,7 @@ class TerminologyExtractor(object):
         self.xmlelpat = re.compile(r"<(?:![[-]|[/?]?[A-Za-z_:])[^>]*>")
         # handles XML/HTML entities (&#32; &#x20; &amp; &my_entity;)
         self.xmlentpat = re.compile(r"&(?:#(?:[0-9]+|x[0-9a-f]+)|[a-z_:][\w.-:]*);",
-                               flags=re.UNICODE | re.IGNORECASE)
+                                    flags=re.UNICODE | re.IGNORECASE)
 
         self.units = 0
         self.glossary = {}
@@ -101,36 +103,35 @@ class TerminologyExtractor(object):
                    '>': frozenset(['word', 'skip']),
                    '@': frozenset(['word', 'phrase'])}
 
-        stopfile = open(self.stopfile, "r")
-        line = 0
-        try:
-            for stopline in stopfile:
-                line += 1
-                stoptype = stopline[0]
-                if stoptype == '#' or stoptype == "\n":
-                    continue
-                elif stoptype == '!':
-                    if stopline[1] == 'C':
-                        self.stopfoldtitle = False
-                        self.stopignorecase = False
-                    elif stopline[1] == 'F':
-                        self.stopfoldtitle = True
-                        self.stopignorecase = False
-                    elif stopline[1] == 'I':
-                        self.stopignorecase = True
+        with open(self.stopfile, "r") as stopfile:
+            line = 0
+            try:
+                for stopline in stopfile:
+                    line += 1
+                    stoptype = stopline[0]
+                    if stoptype == '#' or stoptype == "\n":
+                        continue
+                    elif stoptype == '!':
+                        if stopline[1] == 'C':
+                            self.stopfoldtitle = False
+                            self.stopignorecase = False
+                        elif stopline[1] == 'F':
+                            self.stopfoldtitle = True
+                            self.stopignorecase = False
+                        elif stopline[1] == 'I':
+                            self.stopignorecase = True
+                        else:
+                            logger.warning("%s:%d - bad case mapping directive",
+                                           self.stopfile, line)
+                    elif stoptype == '/':
+                        self.stoprelist.append(re.compile(stopline[1:-1] + '$'))
                     else:
-                        logger.warning("%s:%d - bad case mapping directive",
-                                       self.stopfile, line)
-                elif stoptype == '/':
-                    self.stoprelist.append(re.compile(stopline[1:-1] + '$'))
-                else:
-                    self.stopwords[stopline[1:-1]] = actions[stoptype]
-        except KeyError as character:
-            logger.warning("%s:%d - bad stopword entry starts with '%s'",
-                           self.stopfile, line, str(character))
-            logger.warning("%s:%d all lines after error ignored",
-                           self.stopfile, line + 1)
-        stopfile.close()
+                        self.stopwords[stopline[1:-1]] = actions[stoptype]
+            except KeyError as character:
+                logger.warning("%s:%d - bad stopword entry starts with '%s'",
+                               self.stopfile, line, str(character))
+                logger.warning("%s:%d all lines after error ignored",
+                               self.stopfile, line + 1)
 
     def clean(self, string):
         """returns the cleaned string that contains the text to be matched"""
@@ -240,7 +241,7 @@ class TerminologyExtractor(object):
         terms = {}
         locre = re.compile(r":[0-9]+$")
         logger.info("%d terms from %d units", len(self.glossary), self.units)
-        for term, translations in self.glossary.iteritems():
+        for term, translations in six.iteritems(self.glossary):
             if len(translations) <= 1:
                 continue
             filecounts = {}
@@ -287,8 +288,8 @@ class TerminologyExtractor(object):
             locmax = 2 * locmin
             if numlocs > locmax:
                 locations = list(locations)[0:locmax]
-                locations.append("(poterminology) %d more locations"
-                                     % (numlocs - locmax))
+                locations.append("(poterminology) %d more locations" %
+                                 (numlocs - locmax))
 
             termunit = create_termunit(term, bestunit, targets, locations, sourcenotes, transnotes, filecounts)
             terms[term] = ((10 * numfiles) + numsources, termunit)
@@ -299,9 +300,8 @@ class TerminologyExtractor(object):
     def filter_terms(self, terms, nonstopmin=1, sortorders=sortorders_default):
         """reduce subphrases from extracted terms"""
         # reduce subphrase
-        termlist = terms.keys()
+        termlist = sorted(terms.keys(), key=len)
         logger.info("%d terms after thresholding", len(termlist))
-        termlist.sort(lambda x, y: cmp(len(x), len(y)))
         for term in termlist:
             words = term.split()
             nonstop = [word for word in words if not self.stopword(word)]
@@ -320,17 +320,17 @@ class TerminologyExtractor(object):
                 if terms[term][0] == terms.get(' '.join(words), [0])[0]:
                     del terms[' '.join(words)]
         logger.info("%d terms after subphrase reduction", len(terms.keys()))
-        termitems = terms.values()
+        termitems = list(terms.values())
         if sortorders is None:
             sortorders = self.sortorders_default
         while len(sortorders) > 0:
             order = sortorders.pop()
             if order == "frequency":
-                termitems.sort(lambda x, y: cmp(y[0], x[0]))
+                termitems.sort(key=itemgetter(0), reverse=True)
             elif order == "dictionary":
-                termitems.sort(lambda x, y: cmp(x[1].source.lower(), y[1].source.lower()))
+                termitems.sort(key=lambda x: x[1].source.lower())
             elif order == "length":
-                termitems.sort(lambda x, y: cmp(len(x[1].source), len(y[1].source)))
+                termitems.sort(key=lambda x: x[1].source)
             else:
                 logger.warning("unknown sort order %s", order)
         return termitems
@@ -388,7 +388,7 @@ class TerminologyOptionParser(optrecurse.RecursiveOptionParser):
         """sets the usage string - if usage not given, uses getusagestring for each option"""
         if usage is None:
             self.usage = "%prog " + " ".join([self.getusagestring(option) for option in self.option_list]) + \
-                    "\n  input directory is searched for PO files, terminology PO file is output file"
+                "\n  input directory is searched for PO files, terminology PO file is output file"
         else:
             super(TerminologyOptionParser, self).set_usage(usage)
 
@@ -396,8 +396,6 @@ class TerminologyOptionParser(optrecurse.RecursiveOptionParser):
         """parses the arguments, and runs recursiveprocess with the resulting options"""
         self.files = 0
         (options, args) = self.parse_args()
-        options.inputformats = self.inputformats
-        options.outputoptions = self.outputoptions
         self.extractor = TerminologyExtractor(foldtitle=options.foldtitle, ignorecase=options.ignorecase,
                                               accelchars=options.accelchars, termlength=options.termlength,
                                               sourcelanguage=options.sourcelanguage,
@@ -420,20 +418,18 @@ class TerminologyOptionParser(optrecurse.RecursiveOptionParser):
         if os.path.isdir(options.output):
             options.output = os.path.join(options.output, "pootle-terminology.pot")
 
-        self.initprogressbar(inputfiles, options)
+        progress_bar = optrecurse.ProgressBar(options.progress, inputfiles)
         for inputpath in inputfiles:
             self.files += 1
             fullinputpath = self.getfullinputpath(options, inputpath)
             success = True
             try:
                 self.processfile(None, options, fullinputpath)
-            except Exception as error:
-                if isinstance(error, KeyboardInterrupt):
-                    raise
+            except Exception:
                 self.warning("Error processing: input %s" % (fullinputpath), options, sys.exc_info())
                 success = False
-            self.reportprogress(inputpath, success)
-        del self.progressbar
+            progress_bar.report_progress(inputpath, success)
+        del progress_bar
         self.outputterminology(options)
 
     def processfile(self, fileprocessor, options, fullinputpath):
@@ -446,12 +442,15 @@ class TerminologyOptionParser(optrecurse.RecursiveOptionParser):
         """saves the generated terminology glossary"""
         termfile = po.pofile()
         logger.info("scanned %d files", self.files)
-        terms = self.extractor.extract_terms(inputmin=options.inputmin, fullmsgmin=options.fullmsgmin,
-                                   substrmin=options.substrmin, locmin=options.locmin)
+        terms = self.extractor.extract_terms(inputmin=options.inputmin,
+                                             fullmsgmin=options.fullmsgmin,
+                                             substrmin=options.substrmin,
+                                             locmin=options.locmin)
         termitems = self.extractor.filter_terms(terms, nonstopmin=options.nonstopmin, sortorders=options.sortorders)
         for count, unit in termitems:
             termfile.units.append(unit)
-        open(options.output, "w").write(str(termfile))
+        with open(options.output, "wb") as fh:
+            termfile.serialize(fh)
 
 
 def fold_case_option(option, opt_str, value, parser):
@@ -467,7 +466,8 @@ def main():
     formats = {"po": ("po", None), "pot": ("pot", None), None: ("po", None)}
     parser = TerminologyOptionParser(formats)
 
-    parser.add_option("-u", "--update", type="string", dest="update",
+    parser.add_option(
+        "-u", "--update", type="string", dest="update",
         metavar="UPDATEFILE", help="update terminology in UPDATEFILE")
 
     parser.add_option("-S", "--stopword-list", type="string", metavar="STOPFILE", dest="stopfile",
@@ -475,36 +475,49 @@ def main():
                       file_discovery.get_abs_data_filename('stoplist-en'))
 
     parser.set_defaults(foldtitle=True, ignorecase=False)
-    parser.add_option("-F", "--fold-titlecase", callback=fold_case_option,
+    parser.add_option(
+        "-F", "--fold-titlecase", callback=fold_case_option,
         action="callback", help="fold \"Title Case\" to lowercase (default)")
-    parser.add_option("-C", "--preserve-case", callback=preserve_case_option,
+    parser.add_option(
+        "-C", "--preserve-case", callback=preserve_case_option,
         action="callback", help="preserve all uppercase/lowercase")
-    parser.add_option("-I", "--ignore-case", dest="ignorecase",
+    parser.add_option(
+        "-I", "--ignore-case", dest="ignorecase",
         action="store_true", help="make all terms lowercase")
 
-    parser.add_option("", "--accelerator", dest="accelchars", default="",
+    parser.add_option(
+        "", "--accelerator", dest="accelchars", default="",
         metavar="ACCELERATORS", help="ignore the given accelerator characters when matching")
 
-    parser.add_option("-t", "--term-words", type="int", dest="termlength", default="3",
+    parser.add_option(
+        "-t", "--term-words", type="int", dest="termlength", default="3",
         help="generate terms of up to LENGTH words (default 3)", metavar="LENGTH")
-    parser.add_option("", "--nonstop-needed", type="int", dest="nonstopmin", default="1",
+    parser.add_option(
+        "", "--nonstop-needed", type="int", dest="nonstopmin", default="1",
         help="omit terms with less than MIN nonstop words (default 1)", metavar="MIN")
-    parser.add_option("", "--inputs-needed", type="int", dest="inputmin",
+    parser.add_option(
+        "", "--inputs-needed", type="int", dest="inputmin",
         help="omit terms appearing in less than MIN input files (default 2, or 1 if only one input file)", metavar="MIN")
-    parser.add_option("", "--fullmsg-needed", type="int", dest="fullmsgmin", default="1",
+    parser.add_option(
+        "", "--fullmsg-needed", type="int", dest="fullmsgmin", default="1",
         help="omit full message terms appearing in less than MIN different messages (default 1)", metavar="MIN")
-    parser.add_option("", "--substr-needed", type="int", dest="substrmin", default="2",
+    parser.add_option(
+        "", "--substr-needed", type="int", dest="substrmin", default="2",
         help="omit substring-only terms appearing in less than MIN different messages (default 2)", metavar="MIN")
-    parser.add_option("", "--locs-needed", type="int", dest="locmin", default="2",
+    parser.add_option(
+        "", "--locs-needed", type="int", dest="locmin", default="2",
         help="omit terms appearing in less than MIN different original source files (default 2)", metavar="MIN")
 
-    parser.add_option("", "--sort", dest="sortorders", action="append",
+    parser.add_option(
+        "", "--sort", dest="sortorders", action="append",
         type="choice", choices=TerminologyExtractor.sortorders_default, metavar="ORDER",
         help="output sort order(s): %s (may repeat option, default is all in above order)" % ', '.join(TerminologyExtractor.sortorders_default))
 
-    parser.add_option("", "--source-language", dest="sourcelanguage", default="en",
+    parser.add_option(
+        "", "--source-language", dest="sourcelanguage", default="en",
         help="the source language code (default 'en')", metavar="LANG")
-    parser.add_option("-v", "--invert", dest="invert",
+    parser.add_option(
+        "-v", "--invert", dest="invert",
         action="store_true", default=False, help="invert the source and target languages for terminology")
     parser.set_usage()
     parser.description = __doc__
